==> openvkl-2.0.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/openvkl-2.0.0/openvkl_Exports-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "openvkl::openvkl" for configuration "None"
set_property(TARGET openvkl::openvkl APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(openvkl::openvkl PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "ispcrt::ispcrt"
  IMPORTED_LOCATION_NONE "/usr/lib/libopenvkl.so.2.0.0"
  IMPORTED_SONAME_NONE "libopenvkl.so.2"
  )

list(APPEND _cmake_import_check_targets openvkl::openvkl )
list(APPEND _cmake_import_check_files_for_openvkl::openvkl "/usr/lib/libopenvkl.so.2.0.0" )

# Import target "openvkl::openvkl_module_cpu_device_4" for configuration "None"
set_property(TARGET openvkl::openvkl_module_cpu_device_4 APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(openvkl::openvkl_module_cpu_device_4 PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "embree"
  IMPORTED_LOCATION_NONE "/usr/lib/libopenvkl_module_cpu_device_4.so.2.0.0"
  IMPORTED_SONAME_NONE "libopenvkl_module_cpu_device_4.so.2"
  )

list(APPEND _cmake_import_check_targets openvkl::openvkl_module_cpu_device_4 )
list(APPEND _cmake_import_check_files_for_openvkl::openvkl_module_cpu_device_4 "/usr/lib/libopenvkl_module_cpu_device_4.so.2.0.0" )

# Import target "openvkl::openvkl_module_cpu_device" for configuration "None"
set_property(TARGET openvkl::openvkl_module_cpu_device APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(openvkl::openvkl_module_cpu_device PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "openvkl::openvkl_module_cpu_device_4"
  IMPORTED_LOCATION_NONE "/usr/lib/libopenvkl_module_cpu_device.so.2.0.0"
  IMPORTED_SONAME_NONE "libopenvkl_module_cpu_device.so.2"
  )

list(APPEND _cmake_import_check_targets openvkl::openvkl_module_cpu_device )
list(APPEND _cmake_import_check_files_for_openvkl::openvkl_module_cpu_device "/usr/lib/libopenvkl_module_cpu_device.so.2.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> openvkl-2.0.1-1-aarch64.pkg.tar.xz: usr/lib/cmake/openvkl-2.0.1/openvkl_Exports-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "openvkl::openvkl" for configuration "None"
set_property(TARGET openvkl::openvkl APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(openvkl::openvkl PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libopenvkl.so.2.0.1"
  IMPORTED_SONAME_NONE "libopenvkl.so.2"
  )

list(APPEND _cmake_import_check_targets openvkl::openvkl )
list(APPEND _cmake_import_check_files_for_openvkl::openvkl "${_IMPORT_PREFIX}/lib/libopenvkl.so.2.0.1" )

# Import target "openvkl::openvkl_module_cpu_device_4" for configuration "None"
set_property(TARGET openvkl::openvkl_module_cpu_device_4 APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(openvkl::openvkl_module_cpu_device_4 PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "embree"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libopenvkl_module_cpu_device_4.so.2.0.1"
  IMPORTED_SONAME_NONE "libopenvkl_module_cpu_device_4.so.2"
  )

list(APPEND _cmake_import_check_targets openvkl::openvkl_module_cpu_device_4 )
list(APPEND _cmake_import_check_files_for_openvkl::openvkl_module_cpu_device_4 "${_IMPORT_PREFIX}/lib/libopenvkl_module_cpu_device_4.so.2.0.1" )

# Import target "openvkl::openvkl_module_cpu_device" for configuration "None"
set_property(TARGET openvkl::openvkl_module_cpu_device APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(openvkl::openvkl_module_cpu_device PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "openvkl::openvkl_module_cpu_device_4"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libopenvkl_module_cpu_device.so.2.0.1"
  IMPORTED_SONAME_NONE "libopenvkl_module_cpu_device.so.2"
  )

list(APPEND _cmake_import_check_targets openvkl::openvkl_module_cpu_device )
list(APPEND _cmake_import_check_files_for_openvkl::openvkl_module_cpu_device "${_IMPORT_PREFIX}/lib/libopenvkl_module_cpu_device.so.2.0.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
